@@ -3,7 +3,7 @@ package Devel::Platform::Match;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-08'; # DATE
 our $DIST = 'Devel-Platform-Match'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,8 +13,9 @@ use Scalar::Util qw(looks_like_number);
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(
-                       parse_platform_spec
                        match_platform
+                       match_platform_bool
+                       parse_platform_spec
                );
 
 our %SPEC;
@@ -154,12 +155,14 @@ our $RE =
   }x;
 
 our %aliases = (
-    "linux-x86"    => "osflag=linux archname=x86",
+    "linux32"      => "osflag=linux archname=i686",
+    "linux64"      => "osflag=linux archname=x86_64",
+
+    "linux-i386"   => "osflag=linux archname=i386",
+    "linux-i686"   => "osflag=linux archname=i686",
     "linux-amd64"  => "osflag=linux archname=x86_64",
     "linux-x86_64" => "osflag=linux archname=x86_64",
-    "linux32"      => "osflag=linux archname=x86",
-    "linux64"      => "osflag=linux archname=x86_64",
-    "win32"        => "osflag=Win32 archname=x86",
+    "win32"        => "osflag=Win32 archname=i686", # or i386?
     "win64"        => "osflag=Win32 archname=x86_64",
     "all"          => "",
 );
@@ -183,8 +186,8 @@ $SPEC{parse_platform_spec} = {
     examples => [
         {
             summary => "coercion of alias",
-            args => {spec=>"linux-x86"},
-            result => [["osflag","=","linux"], ["arch","=", "x86"]],
+            args => {spec=>"linux32"},
+            result => [["osflag","=","linux"], ["archname","=", "i686"]],
             test => 0, #args_as array not supported yet?
         },
         {
@@ -368,6 +371,11 @@ sub match_platform {
     }];
 }
 
+sub match_platform_bool {
+    my $res = match_platform(@_);
+    $res->[0] == 200 && $res->[2] ? 1:0;
+}
+
 1;
 # ABSTRACT: Match platform information with platform specification
 
@@ -383,11 +391,15 @@ Devel::Platform::Match - Match platform information with platform specification
 
 =head1 VERSION
 
-This document describes version 0.003 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
+This document describes version 0.004 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
 
 =head1 SYNOPSIS
 
- use Devel::Platform::Match qw(match_platform parse_platform_spec);
+ use Devel::Platform::Match qw(
+     match_platform
+     match_platform_bool
+     parse_platform_spec
+ );
 
  # assuming we're on an Ubuntu Linux 20.04 64bit
  my $envres = match_platform("osflag=linux"); # -> [200, "OK", 1]
@@ -422,12 +434,13 @@ A platform specification with zero clauses (C<"">) will match all platforms.
 For convenience, some aliases will be coerced into a proper platform
 specification first:
 
-    "linux-x86"    => "osflag=linux archname=x86",
+    "linux32"      => "osflag=linux archname=i686",
+    "linux64"      => "osflag=linux archname=x86_64",
+    "linux-i386"   => "osflag=linux archname=i386",
+    "linux-i686"   => "osflag=linux archname=i686",
     "linux-amd64"  => "osflag=linux archname=x86_64",
     "linux-x86_64" => "osflag=linux archname=x86_64",
-    "linux32"      => "osflag=linux archname=x86",
-    "linux64"      => "osflag=linux archname=x86_64",
-    "win32"        => "osflag=Win32 archname=x86",
+    "win32"        => "osflag=Win32 archname=i686",
     "win64"        => "osflag=Win32 archname=x86_64",
     "all"          => "",
 
@@ -530,7 +543,7 @@ Examples:
 
 =item * coercion of alias:
 
- parse_platform_spec("linux-x86"); # -> undef
+ parse_platform_spec("linux32"); # -> undef
 
 =item * Example #2:
 
@@ -555,6 +568,15 @@ Arguments ('*' denotes required arguments):
 
 Return value:  (array)
 
+
+=head2 match_platform_bool
+
+Usage:
+
+ my $match = match_platform_bool($spec [ , $info [ , $quiet ] ]); # -> bool
+
+Just like L</match_platform> but return a simple boolean value.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Devel-Platform-Match>.
